@@ -1,6 +1,6 @@
 package WWW::FetchStory::Fetcher::FanfictionNet;
 {
-  $WWW::FetchStory::Fetcher::FanfictionNet::VERSION = '0.1815';
+  $WWW::FetchStory::Fetcher::FanfictionNet::VERSION = '0.1816';
 }
 use strict;
 use warnings;
@@ -10,7 +10,7 @@ WWW::FetchStory::Fetcher::FanfictionNet - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1815
+version 0.1816
 
 =head1 DESCRIPTION
 
@@ -241,10 +241,11 @@ sub parse_toc {
     }
     $info{title} = $self->parse_title(%args);
     my $auth_url = '';
-    if ($content =~ m#<a href='(/u/\d+/[-\w]+)'>([^<]+)</a>#s)
+    if ($content =~ m#href='(/u/\d+/[-\w]+)'>([^<]+)</a>#s)
     {
 	$auth_url = $1;
 	$info{author} = $2;
+        warn "author from URL=$info{author}\n" if ($self->{verbose} > 1);
     }
     else
     {
@@ -272,7 +273,6 @@ sub parse_toc {
 	$info{summary} = $self->parse_summary(%args);
     }
 
-
     # get the mobile version of the page in order to parse the other stuff
     my $mob_url = $args{url};
     $mob_url =~ s/www/m/;
